@@ -17,11 +17,11 @@ Config::Abstraction - Configuration Abstraction Layer
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 SYNOPSIS
 
@@ -325,6 +325,9 @@ sub _load_config
 					if(($data =~ /^\s*<\?xml/) || ($data =~ /<\/.+>/)) {
 						$self->_load_driver('XML::Simple', ['XMLin']);
 						$data = XMLin($path, ForceArray => 0, KeyAttr => []);
+						if($data) {
+							$self->{'type'} = 'XML';
+						}
 					} elsif($data =~ /\{.+:.\}/s) {
 						$self->_load_driver('JSON::Parse');
 						# CPanel::JSON is very noisy, so be careful before attempting to use it
@@ -338,6 +341,9 @@ sub _load_config
 						} else {
 							undef $data;
 						}
+						if($data) {
+							$self->{'type'} = 'JSON';
+						}
 					} else {
 						undef $data;
 					}
@@ -361,6 +367,9 @@ sub _load_config
 									}
 								}
 							}
+							if($data) {
+								$self->{'type'} = 'YAML';
+							}
 						}
 						if((!$data) || (ref($data) ne 'HASH')) {
 							$self->_load_driver('Config::IniFiles');
@@ -369,6 +378,9 @@ sub _load_config
 									my $section = $_;
 									$section => { map { $_ => $ini->val($section, $_) } $ini->Parameters($section) }
 								} $ini->Sections() };
+								if($data) {
+									$self->{'type'} = 'INI';
+								}
 							}
 							if((!$data) || (ref($data) ne 'HASH')) {
 								# Maybe XML without the leading XML header
@@ -376,7 +388,10 @@ sub _load_config
 								eval { $data = XMLin($path, ForceArray => 0, KeyAttr => []) };
 								if((!$data) || (ref($data) ne 'HASH')) {
 									$self->_load_driver('Config::Auto');
-									$data = Config::Auto->new(source => $path)->parse();
+									my $ca = Config::Auto->new(source => $path);
+									if($data = $ca->parse()) {
+										$self->{'type'} = $ca->format();
+									}
 								}
 							}
 						}
@@ -386,7 +401,7 @@ sub _load_config
 					if($@) {
 						$logger->warn(ref($self), ' ', __LINE__, $@);
 					} else {
-						$logger->debug(ref($self), ' ', __LINE__, ": Loaded data from $path");
+						$logger->debug(ref($self), ' ', __LINE__, ': Loaded data from', $self->{'type'}, "file $path");
 					}
 				}
 				if(scalar(keys %merged)) {
@@ -405,13 +420,19 @@ sub _load_config
 	}
 
 	# Merge ENV vars
+	my $prefix = $self->{env_prefix};
+	$prefix =~ s/_$//;
 	for my $key (keys %ENV) {
 		next unless $key =~ /^$self->{env_prefix}(.*)$/;
 		my $path = lc $1;
-		my @parts = split /__/, $path;
-		my $ref = \%merged;
-		$ref = ($ref->{$_} //= {}) for @parts[0..$#parts-1];
-		$ref->{ $parts[-1] } = $ENV{$key};
+		if($path =~ /__/) {
+			my @parts = split /__/, $path;
+			my $ref = \%merged;
+			$ref = ($ref->{$_} //= {}) for @parts[0..$#parts-1];
+			$ref->{ $parts[-1] } = $ENV{$key};
+		} else {
+			$merged{$prefix}->{$path} = $ENV{$key};
+		}
 	}
 
 	# Merge command line options
